@@ -2,17 +2,20 @@
 
 # -----------------------------------------------------------------------------
 #
-#  NES by Skriptke
-#  Copyright 2009 - 2010 Enrique F. Castañón
+#  Nes by Skriptke
+#  Copyright 2009 - 2010 Enrique Castañón 
 #  Licensed under the GNU GPL.
 #
+#  CPAN:
+#  http://search.cpan.org/dist/Nes/
+#
 #  Sample:
 #  http://nes.sourceforge.net/
 #
 #  Repository:
 #  http://github.com/Skriptke/nes
 # 
-#  Version 1.00_01
+#  Version 1.03
 #
 #  DB.pm
 #
@@ -73,8 +76,8 @@
 
     eval {
       $self->{'dbh'}->disconnect;
-      $self->{'errstr'} = $DBI::errstr;
-      $self->{'error'}  = $DBI::errstr;
+#      $self->{'errstr'} = $DBI::errstr;
+      $self->{'error'}  .= $DBI::errstr;
     };  
 
     $self->{'dbh'} = 0;
@@ -118,16 +121,14 @@
       $self->{'filas'} = $sth->execute();
       $self->{'rows'} = $self->{'dbh'}->rows;
       $self->{'errstr'} = $self->{'dbh'}->errstr;
-    };      
+    };   
+    
     return if $DBI::errstr;
-  
     while( $resultado = $sth->fetchrow_hashref ) {
       push(@encontrados, $resultado);
     }
-  
-    $sth->finish();
-    
-    $self->close();
+    $sth->finish(); 
+    $self->close();    
     
     return @encontrados;
   }
@@ -146,15 +147,15 @@
       $self->{'filas'} = $sth->execute();
       $self->{'rows'} = $self->{'dbh'}->rows;
       $self->{'errstr'} = $self->{'dbh'}->errstr;
-    };      
+    };
+
     return if $DBI::errstr;
-  
+
     while( $resultado = $sth->fetchrow_hashref ) {
       push(@encontrados, $resultado);
     }
-  
     $sth->finish();
-    
+
     return @encontrados;
   }
   
