@@ -3,16 +3,19 @@
 # -----------------------------------------------------------------------------
 #
 #  Nes by Skriptke
-#  Copyright 2009 - 2010 Enrique F. Castañón
+#  Copyright 2009 - 2010 Enrique F. Castañón Barbero
 #  Licensed under the GNU GPL.
 #
+#  CPAN:
+#  http://search.cpan.org/dist/Nes/
+#
 #  Sample:
 #  http://nes.sourceforge.net/
 #
 #  Repository:
 #  http://github.com/Skriptke/nes
 # 
-#  Version 1.00_01
+#  Version 1.03
 #
 #  Setting.pm
 #
@@ -26,15 +29,16 @@
 
   sub new {
     my $class = shift;
-          
-    utl::cleanup(\$instance) if $ENV{'MOD_PERL'};   
+    my ( $ntop, $ndir ) = @_;
 
+    utl::cleanup(\$instance) if $ENV{'MOD_PERL'};
     return $instance if $instance;
 
     my $level       = utl::get_file_dir();
     my $file_name   = '.nes.cfg';
-    my $nes_dir     = $ENV{'SCRIPT_NAME'} || '/cgi-bin/nes';  # default: /cgi-bin/nes
-    my $nes_top_dir = $ENV{'SCRIPT_FILENAME'} || ''; 
+    $ndir           = '/cgi-bin/nes' if $ntop && !$ndir;
+    my $nes_dir     = $ndir || $ENV{'SCRIPT_NAME'} || '/cgi-bin/nes';  # default: /cgi-bin/nes
+    my $nes_top_dir = $ntop || $ENV{'SCRIPT_FILENAME'} || ''; 
     $nes_dir        =~ s/\/[^\/]*\.cgi|pl$//;
     $nes_top_dir    =~ s/\/[^\/]*\.cgi|pl$//;
 
@@ -43,7 +47,7 @@
 
     my $self = {
       tmp_dir        => '/tmp/nes',
-      tmp_suffix     => '.nes_file_temp',
+      tmp_suffix     => '.nes_tmp',
       tmp_clear      => 0, # borrar los archivos temporales de más del tiempo indicado, si es 0 no borra
       top_dir        => $top_dir,              # document root
       nes_top_dir    => $nes_top_dir,          # nes dir install
@@ -51,7 +55,10 @@
       plugin_dir     => $nes_dir . '/plugin',
       obj_dir        => $nes_dir . '/obj',
       plugin_top_dir => $nes_top_dir . '/plugin',
-      obj_top_dir    => $nes_top_dir . '/obj',      
+      obj_top_dir    => $nes_top_dir . '/obj',     
+      obj_form       => $nes_top_dir . '/obj/Nes/form',
+      img_dir        => $nes_dir . '/images',
+      js_dir         => $nes_dir . '/js',
       time_zone      => 'Europe/Madrid',       # * sin implementar *
       locale         => '',                    # es_ES.utf8
       session_prefix => 'NESSESSION',
@@ -106,8 +113,9 @@
         my $line = $_;
         next if $line =~ /^#/;
         next if $line =~ /^$/;
-        my ( $key, $value ) = split( /\s*=\s*/, $line, 2 );
-        my ( $eval ) = $key =~ s/[\@\%\$]$//;
+        my ( $key, $value ) = split( /=\s*/, $line, 2 );
+        $key =~ s/\s*(\@|\%|\$)?$//;
+        my $eval = $1 || 0;
         $value =~ s/\s*$//;
 
         # impide que se reescriba 'set';
@@ -122,9 +130,9 @@
             $eval = '@' if ref( $self->{$key} ) eq 'ARRAY';
             $eval = '%' if ref( $self->{$key} ) eq 'HASH';
             $eval = '$' if ref( $self->{$key} ) eq 'SCALAR';
-            @{ $self->{$key} } = eval { $value } if $eval eq '@';
+            @{ $self->{$key} } = eval   $value  if $eval eq '@';
             %{ $self->{$key} } = eval { $value } if $eval eq '%';
-            $self->{$key}      = eval { $value } if $eval eq '$';
+            $self->{$key}      = eval  "$value"  if $eval eq '$';
           } elsif ( ref( $self->{$key} ) eq 'ARRAY' ) {
             @{ $self->{$key} } = split( /,/, $value );
           } else {
@@ -144,6 +152,9 @@
     $self->{'obj_dir'}        =~ s/[\/\\]$//;
     $self->{'plugin_top_dir'} =~ s/[\/\\]$//;
     $self->{'obj_top_dir'}    =~ s/[\/\\]$//;
+    $self->{'obj_form'}       =~ s/[\/\\]$//;
+
+    push( @INC, ( $self->{'plugin_top_dir'}, $self->{'obj_top_dir'}, $self->{'obj_form'} )  );
     
     return;
   }
